@@ -1,6 +1,3 @@
-# $Id: bootstrap 8036 2011-01-27 11:56:11Z joostvb $
-# $URL: https://ilk.uvt.nl/svn/trunk/sources/ucto/trunk/bootstrap $
-
 # bootstrap - script to bootstrap the distribution rolling engine
 
 # usage:
@@ -21,8 +18,6 @@
 automake=automake
 aclocal=aclocal
 
-ln -s README.md README
-
 # if you want to autogenerate a ChangeLog form svn:
 #
 #  svn2cl, a python script, as used in the GNU Enterprise project.
@@ -98,4 +93,3 @@ AUTOMAKE=automake ACLOCAL=aclocal autoreconf --install \
 # aclocal-1.9 \
 #     && automake-1.9 --add-missing --verbose --gnu \
 #     && autoconf
-
