@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006 - 2018
+  Copyright (c) 2006 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
 
@@ -30,7 +30,7 @@
 #include "libfolia/folia_utils.h"
 #include "libfolia/folia_impl.h"
 #include "libfolia/folia_document.h"
-#include "libfolia/folia_builder.h"
-#include "libfolia/folia_processor.h"
+#include "libfolia/folia_engine.h"
+#include "libfolia/folia_provenance.h"
 
 #endif
