@@ -35,7 +35,7 @@ $exe --strip --KANON "$2" --output $t2
 diff $t1 $t2
 if [ $? -ne 0 ]
 then
-    echo "$1 and $2 are different"
+    echo "foliadiff.sh: differences in: $1 $2"
     exit 1
 fi
 
