@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006 - 2018
+  Copyright (c) 2006 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
 
@@ -49,16 +49,16 @@ int main() {
     return EXIT_FAILURE;
   }
   cout << " Creating a document from scratch: ";
-  Document d( "id='example'" );
+  Document d( "xml:id='example'" );
   d.declare( AnnotationType::TOKEN, "adhocset", "annotator='proycon'" );
-  if ( d.defaultset(AnnotationType::TOKEN) != "adhocset"
+  if ( d.default_set(AnnotationType::TOKEN) != "adhocset"
        ||
-       d.defaultannotator(AnnotationType::TOKEN) != "proycon" ){
+       d.default_annotator(AnnotationType::TOKEN) != "proycon" ){
     cout << " Defaultset or defaultannotator does not match" << endl;
     return EXIT_FAILURE;
   }
   string id = d.id() + ".text.1";
-  KWargs kw = getArgs( "id='" + id + "'" );
+  KWargs kw = getArgs( "xml:id='" + id + "'" );
   FoliaElement *text = d.addText( kw );
   kw.clear();
   kw = getArgs( "generate_id='" + text->id() + "'" );
@@ -87,24 +87,27 @@ int main() {
   cout << s->text() << endl;
   UnicodeString dirty = "    A    dir\ty \n  string\r.\n   ";
   UnicodeString clean = normalize_spaces( dirty );
-  UnicodeString wanted = "A dirty string.";
+  UnicodeString wanted = "A dir y string .";
   if ( clean != wanted ){
-    cerr << "normalize_space() failed: got:'" << clean << "'"
+    cerr << "normalize_space() test 1 failed: got:'" << clean << "'"
 	 << "                 but expected:'" << wanted << "'" << endl;
+    return EXIT_FAILURE;
   }
   dirty = "\n";
   clean = normalize_spaces( dirty );
-  wanted = " ";
+  wanted = "";
   if ( clean != wanted ){
-    cerr << "normalize_space() failed: got:'" << clean << "'"
+    cerr << "normalize_space() test 2 failed: got:'" << clean << "'"
 	 << "                 but expected:'" << wanted << "'" << endl;
+    return EXIT_FAILURE;
   }
-  dirty = "\r    ";
+  dirty = "\r x   ";
   clean = normalize_spaces( dirty );
-  wanted = " ";
+  wanted = "x";
   if ( clean != wanted ){
-    cerr << "normalize_space() failed: got:'" << clean << "'"
+    cerr << "normalize_space() test 3 failed: got:'" << clean << "'"
 	 << "                 but expected:'" << wanted << "'" << endl;
+    return EXIT_FAILURE;
   }
   return EXIT_SUCCESS;
 }
